@@ -18,15 +18,21 @@ if [ -e usr/share/glib-2.0/schemas ]; then
   fi
 fi
 
-( cd usr/lib ; rm -rf libgck-1.so )
-( cd usr/lib ; ln -sf libgck-1.so.0.0.0 libgck-1.so )
-( cd usr/lib ; rm -rf libgcr-base-3.so.1 )
-( cd usr/lib ; ln -sf libgcr-base-3.so.1.0.0 libgcr-base-3.so.1 )
+( cd usr/lib ; rm -rf libgcr-3.so )
+( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so )
 ( cd usr/lib ; rm -rf libgck-1.so.0 )
 ( cd usr/lib ; ln -sf libgck-1.so.0.0.0 libgck-1.so.0 )
+( cd usr/lib ; rm -rf libgcr-3.so.1.0.0 )
+( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so.1.0.0 )
+( cd usr/lib ; rm -rf libgcr-3.so.1 )
+( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-3.so.1 )
+( cd usr/lib ; rm -rf libgck-1.so )
+( cd usr/lib ; ln -sf libgck-1.so.0.0.0 libgck-1.so )
 ( cd usr/lib ; rm -rf libgcr-base-3.so )
 ( cd usr/lib ; ln -sf libgcr-base-3.so.1.0.0 libgcr-base-3.so )
-( cd usr/lib ; rm -rf libgcr-3.so.1 )
-( cd usr/lib ; ln -sf libgcr-3.so.1.0.0 libgcr-3.so.1 )
-( cd usr/lib ; rm -rf libgcr-3.so )
-( cd usr/lib ; ln -sf libgcr-3.so.1.0.0 libgcr-3.so )
+( cd usr/lib ; rm -rf libgcr-ui-3.so )
+( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-ui-3.so )
+( cd usr/lib ; rm -rf libgcr-base-3.so.1 )
+( cd usr/lib ; ln -sf libgcr-base-3.so.1.0.0 libgcr-base-3.so.1 )
+( cd usr/lib ; rm -rf libgcr-ui-3.so.1 )
+( cd usr/lib ; ln -sf libgcr-ui-3.so.1.0.0 libgcr-ui-3.so.1 )
